Module ground_truth

Module ground_truth 

Enums

MultivecAggregationMethod
ParseAggrError

Functions

compute_ground_truth_from_data
Computes the true nearest neighbors for a set of queries and dataset iterators
compute_ground_truth_from_datafiles
Computes the true nearest neighbors for a set of queries and writes them to a file.
compute_multivec_ground_truth_from_data
compute_multivec_ground_truth_from_datafiles
Computes the true nearest neighbors for a set of queries and writes them to a file.
compute_range_ground_truth_from_data
compute_range_ground_truth_from_datafiles
Computes range-search ground truth for a set of queries and writes it to a file.
read_labels_and_compute_bitmap