pub fn init_subscriber()Expand description
Create a default subscriber logging messages to stdout and respecting the RUST_LOG
environment variable.
If the environment variable is not set - then the “info” level will be used.
pub fn init_subscriber()Create a default subscriber logging messages to stdout and respecting the RUST_LOG
environment variable.
If the environment variable is not set - then the “info” level will be used.