init_test_subscriber

Function init_test_subscriber 

pub fn init_test_subscriber() -> DefaultGuard
Create a subscriber for the integration tests.

This subscriber returns a Guard that will only install the subscriber locally, allowing test threads to have non-conflicting subscribers.