pub struct DimensionValues { /* private fields */ }Expand description
A simple struct to contain the underlying dimension of the data and its full-precision vector dimension.
dimis the length of the vector when represented with the underlying datatypefull_dimis the length of the vector when converted to a full-precision slice, i.e. f32
Notes
These values are the same when using primitive data types to represent the vectors
such as half::f16 or f32, however, for quantized vectors used in place of
full-preicision vectors such as [common::MinMaxElement] these might be different.
Implementations