Enums
Functions
- compute_
ground_ truth_ from_ data - Computes the true nearest neighbors for a set of queries and dataset iterators
- compute_
ground_ truth_ from_ datafiles - Computes the true nearest neighbors for a set of queries and writes them to a file.
- compute_
multivec_ ground_ truth_ from_ data - compute_
multivec_ ground_ truth_ from_ datafiles - Computes the true nearest neighbors for a set of queries and writes them to a file.
- compute_
range_ ground_ truth_ from_ data - compute_
range_ ground_ truth_ from_ datafiles - Computes range-search ground truth for a set of queries and writes it to a file.
- read_
labels_ and_ compute_ bitmap